<template>
	<div ref="amisPageRef" class="amis-page"></div>
</template>

<script setup lang="ts">
import { Local } from '@icon-park/vue-next';

import 'amis/sdk/sdk.js';
import { onMounted, onUnmounted, ref } from 'vue';
import { NO_AUTH_API_LIST } from '/@/api/ai/chat';
import { LOGIN_URL, TEL_LOGIN_URL } from '/@/api/ai/user';
import { MAIN_URL } from '/@/constants';
import router from '/@/router';
import { accessSessionKey, handleNoAuth } from '/@/utils/request';

const amisPageRef = ref<HTMLDivElement>(null);

const schema = {
	type: 'page',
	title: '表单页面',
	body: [
		{
			type: 'form',
			mode: 'horizontal',
			api: {
				url: '/system/get_sys_notify_list',
				dataType: 'form',
			},

			body: [
				{
					label: 'Name',
					type: 'input-text',
					name: 'name',
				},
				{
					label: 'Email',
					type: 'input-email',
					placeholder: '请输入邮箱地址',
					name: 'email',
				},
				// {
				// 	type: 'editor',
				// 	name: 'js',
				// 	label: 'JS',
				// 	language: 'javascript',
				// },
			],
		},
	],
};
let amisInstance = null;
onMounted(() => {
	let amis = amisRequire('amis/embed');
	amisInstance = amis.embed(
		'.amis-page',
		schema,
		{
			
		},
		{
			requestAdaptor(api) {
				// 支持异步，可以通过 api.mockResponse 来设置返回结果，跳过真正的请求发送
				// 此功能自定义 fetcher 的话会失效
				// api.context 中包含发送请求前的上下文信息
				// 获取本地的 token
				const accessSession = Local.get(accessSessionKey);
				if (!NO_AUTH_API_LIST.includes(api.url)) {
					if (accessSession) {
						// 将 token 添加到请求报文头中
						api.headers['hswatersession'] = accessSession;
					} else {
						if (api.url !== LOGIN_URL && api.url !== TEL_LOGIN_URL) {
							handleNoAuth(api.url);
							throw '权限验证失败';
						}
					}
				}

				api.url = `${MAIN_URL}${api.url}`;
				return api;
			},
			
		}
	);
});

onUnmounted(()=>{
	amisInstance?.unmount();
	
})
</script>
<style scoped lang="scss"></style>
